<?php

class Database {
	
	public function __construct() {
		$this->fingerprints = array();
		$this->pings = array();
	}
	
	
	private function save() {
		return file_put_contents('database', serialize($this));
	}
	public function close() {
		
	}
	
	/**
	 * Create a new Fingerprint in the database.
	 * Return the created Fingerprint on success, and false on error.
	 */
	public function createFingerprint($fingerprint, $name) {
		$f = new Fingerprint($fingerprint, $name);
		$this->fingerprints[] = $f;
		if (!$this->save()) return false;
		return $f;
	}
	
	public function getFingerprint($fingerprint) {
		foreach ($this->fingerprints as $f) {
			if ($f->fingerprint == $fingerprint)
				return $f;
		}
		return null;
	}
	
	public function getFingerprintByName($name) {
		foreach ($this->fingerprints as $f) {
			if ($f->name == $name)
				return $f;
		}
		return null;
	}
	
	/**
	 * Create a new Ping in the database.
	 * Return the created Ping on success, and false on error.
	 */
	public function createPing($fingerprint) {
		$p = new Ping($fingerprint, time());
		$this->pings[] = $p;
		if (!$this->save()) return false;
		return $p;
	}
	
	// Return an array with the most recent pings.
	public function getRecentPings() {
		$ps = [];
		$t = time() - 10; // 10 seconds ago.
		foreach ($this->pings as $p) {
			if ($t < $p->timeCreated)
				$ps[] = $p;
		}
		
		// Remove old pings (bad practice: hidden side-effect).
		$this->pings = $ps;
		$this->save();
		
		return $ps;
	}
	
	public function getFingerprints() {
		return $this->fingerprints;
	}
	
	/**
	 * Return the Database object.
	 * If the database does not exist, a new one is created.
	 * Return false on error.
	 */
	public static function connect() {
		if (file_exists('database')) {
			$contents = file_get_contents('database');
			return unserialize($contents);
		} else {
			return new Database();
		}
	}
}

class Fingerprint {
	public function __construct($fingerprint, $name) {
		$this->fingerprint = $fingerprint;
		$this->name = $name;
	}
}

class Ping {
	public function __construct($fingerprint, $timeCreated) {
		$this->fingerprint = $fingerprint;
		$this->timeCreated = $timeCreated;
	}
}
