const FP_CONFIG = {
	excludeUserAgent: true, // user agent should not take part in FP calculation
	excludeLanguage: true, // browser language 
	excludeColorDepth: true, // color depth
	excludeScreenResolution: false, // screen resolution
	excludeAvailableScreenResolution: false,
	excludeTimezoneOffset: false, // user time zone
	excludeSessionStorage: true, // user browser support of session storage
	excludeIndexedDB: true, // user browser support of IndexedDB
	excludeAddBehavior: true, // IE specific 'AddBehavior' method detection
	excludeOpenDatabase: true, // user browser support of OpenDatabase
	excludeCpuClass: false, // detection of CPU class
	excludePlatform: false, // detection of OS platform
	excludeDoNotTrack: true, // is DoNotTrack set
	excludeCanvas: true, // skip canvas fingerprinting entirely (you will most likely not need to set this to true)
	excludeWebGL: true, // skip WebGL fingerprinting
	excludeAdBlock: true, // skip AdBlock detection
	excludeHasLiedLanguages: true, // skip check if user is trying to hide his browser language
	excludeHasLiedResolution: true, // skip check if user is trying to hide his screen resolution
	excludeHasLiedOs: false, // skip check if user is trying to hide his OS info
	excludeHasLiedBrowser: true, // skip check if user is trying to hide his browser information
	excludeJsFonts: true, // skip font detection with CSS "side channel"
	excludeFlashFonts: false, // skip font detection with Flash (disabled by default)
	excludePlugins: true, // skip plugin enumeration/detection
	excludeIEPlugins: true, // skip IE plugin enumeration/detection
	excludeTouchSupport: false, // skip touch screen specific info fingerprinting
	excludePixelRatio: false, // skip device pixel ratio
	excludeHardwareConcurrency: false // skip hardware concurrency
};


var fingerprint = null;  // Will look like { fingerprint: ..., name: ... }.

$(function() {
	$('body').css('background-color', '#210C16');

	new Fingerprint2(FP_CONFIG).get(function(fingerprint, components) {
		console.log("Fingerprint hash: " + fingerprint)
		console.log(components);
		$.ajax({
			type: 'GET',
			url: 'get-fingerprint.php',
			data: { fingerprint },
			dataType: 'json',
			success: getFingerprintSuccess,
			error: getFingerprintError
		});
	});
});
function getFingerprintSuccess(data) {
	console.log(data);
	if (data.error) return $('#page-error').show();
	if (!data.fingerprint) return $('#page-create').show();
	$('#page-list').show();
	$('#page-list-name').html(data.fingerprint.name);
	fingerprint = data.fingerprint;
	ping();
}
function getFingerprintError(error) {
	console.log(error);
	$('#page-error').show();
}


function onCreate(e) {
	e.preventDefault(); // Prevent refresh.
	
	let name = $('#page-create-name').val();
	if (name.length == 0)
		return $('#page-create-error').html("Cannot be empty.");
	var patt = new RegExp("^[a-zA-Z\d]+$");
	if (!patt.test(name))
		return $('#page-create-error').html("Letters and numbers only please.");
	
	new Fingerprint2(FP_CONFIG).get(function(fingerprint) {
		$.ajax({
			type: 'POST',
			url: 'create-fingerprint.php',
			data: { fingerprint, name },
			dataType: 'json',
			success: onCreateSuccess,
			error: onCreateError
		});
	});
}
function onCreateSuccess(data) {
	console.log(data);
	if (data.nameTaken)
		return $('#page-create-error').html("Name taken. Try a nickname.");
	if (data.error || !data.fingerprint)
		return $('#page-create-error').html("Something went wrong.");
	$('#page-create').hide();
	$('#page-list').show();
	$('#page-list-name').html(data.fingerprint.name);
	fingerprint = data.fingerprint;
	ping();
}
function onCreateError(error) {
	console.log(error);
	$('#page-create-error').html("Something went wrong.");
}


function ping() {
	$.ajax({
		type: 'POST',
		url: 'create-ping.php',
		data: { fingerprint: fingerprint.fingerprint },
		dataType: 'json',
		success: onPingSuccess,
		error: onPingError
	});
}
function onPingSuccess(data) {
	console.log(data);
	let { fingerprints, pings, error } = data,
		lis = '';
	if (!error || fingerprints || pings) {
		fingerprints.sort((a, b) => (a.name > b.name ? 1 : -1));
		for (i in fingerprints) {
			let f = fingerprints[i],
				offline = pings.findIndex(p => p.fingerprint == f.fingerprint) == -1;
			lis += (`<li class="${offline ? 'offline' : ''}">${f.name}</li>`);
		}
		$('#page-list-list').html(lis);
	}
	setTimeout(ping, 6000);
}
function onPingError(error) {
	console.log(error);
	setTimeout(ping, 6000);
}
